@@ -1,30 +1,24 @@
-use crate::{error::Error, Res};
-use ignore::gitignore::GitignoreBuilder;
-use notify::{Event, EventKind, RecursiveMode, Watcher};
+use crate::{error::Error, open_repo, Res};
+use notify::{Event, EventKind, RecommendedWatcher, RecursiveMode, Watcher};
 use std::{
     path::Path,
     sync::{
         atomic::{AtomicBool, Ordering},
         Arc,
     },
-    thread,
 };
 
 pub struct FileWatcher {
+    _watcher: RecommendedWatcher,
     pending_updates: Arc<AtomicBool>,
 }
 
 impl FileWatcher {
-    pub fn new(path: &Path) -> Res<Self> {
+    pub fn new(repo_dir: &Path) -> Res<Self> {
         let pending_updates = Arc::new(AtomicBool::new(false));
         let pending_updates_w = pending_updates.clone();
 
-        let gitignore = GitignoreBuilder::new(path)
-            .add_line(None, super::LOG_FILE_NAME)
-            .map_err(Error::FileWatcherGitignore)?
-            .build()
-            .unwrap();
-
+        let repo = open_repo(repo_dir)?;
         let mut watcher = notify::recommended_watcher(move |res: Result<Event, notify::Error>| {
             if let Ok(event) = res {
                 if !is_changed(&event) {
@@ -32,8 +26,8 @@ impl FileWatcher {
                 }
 
                 for path in event.paths {
-                    if !gitignore.matched(&path, path.is_dir()).is_ignore() {
-                        log::info!("File changed: {:?}", path);
+                    if !repo.status_should_ignore(&path).unwrap_or(false) {
+                        log::info!("File changed: {:?} ({:?})", path, event.kind);
                         pending_updates_w.store(true, Ordering::Relaxed);
                         break;
                     }
@@ -42,17 +36,19 @@ impl FileWatcher {
         })
         .map_err(Error::FileWatcher)?;
 
-        let path_buf = path.to_owned();
-        thread::spawn(move || {
-            if let Err(err) = watcher
-                .watch(path_buf.as_ref(), RecursiveMode::Recursive)
-                .map_err(Error::FileWatcher)
-            {
-                log::error!("Couldn't start file-watcher due to: {}", err);
-            }
-        });
+        let path_buf = repo_dir.to_owned();
+        watcher
+            .watch(&path_buf, RecursiveMode::Recursive)
+            .map_err(Error::FileWatcher)?;
+        log::info!(
+            "File watcher started (kind: {:?})",
+            RecommendedWatcher::kind()
+        );
 
-        Ok(Self { pending_updates })
+        Ok(Self {
+            _watcher: watcher,
+            pending_updates,
+        })
     }
 
     pub fn pending_updates(&self) -> bool {
