@@ -1,3 +1,4 @@
+pub mod app;
 mod bindings;
 pub mod cli;
 mod cmd_log;
@@ -8,20 +9,19 @@ mod git;
 mod git2_opts;
 pub mod gitu_diff;
 mod highlight;
+mod item_data;
 mod items;
 mod key_parser;
 mod menu;
 mod ops;
 mod prompt;
 mod screen;
-pub mod state;
 mod syntax_parser;
 pub mod term;
 #[cfg(test)]
 mod tests;
 mod ui;
 
-use crossterm::event::{self, Event, KeyCode, KeyEvent, KeyEventState, KeyModifiers};
 use error::Error;
 use git2::Repository;
 use items::Item;
@@ -33,6 +33,7 @@ use std::{
     time::Duration,
 };
 use term::Term;
+use termwiz::input::{InputEvent, KeyCode, KeyEvent, Modifiers};
 
 pub const LOG_FILE_NAME: &str = "gitu.log";
 
@@ -80,7 +81,7 @@ pub fn run(args: &cli::Args, term: &mut Term) -> Res<()> {
     let repo = open_repo(&dir)?;
     let config = Rc::new(config::init_config()?);
 
-    let mut state = state::State::create(
+    let mut app = app::App::create(
         Rc::new(repo),
         term.size().map_err(Error::Term)?,
         args,
@@ -94,17 +95,17 @@ pub fn run(args: &cli::Args, term: &mut Term) -> Res<()> {
         };
 
         for event in keys_to_events(&keys) {
-            state.handle_event(term, event)?;
+            app.handle_event(term, event)?;
         }
     }
 
-    state.redraw_now(term)?;
+    app.redraw_now(term)?;
 
     if args.print {
         return Ok(());
     }
 
-    state.run(term, Duration::from_millis(100))?;
+    app.run(term, Duration::from_millis(100))?;
 
     Ok(())
 }
@@ -139,14 +140,12 @@ fn open_repo_from_env() -> Res<Repository> {
     }
 }
 
-fn keys_to_events(keys: &[(KeyModifiers, KeyCode)]) -> Vec<Event> {
+fn keys_to_events(keys: &[(Modifiers, KeyCode)]) -> Vec<InputEvent> {
     keys.iter()
         .map(|(mods, key)| {
-            Event::Key(KeyEvent {
-                code: *key,
+            InputEvent::Key(KeyEvent {
+                key: *key,
                 modifiers: *mods,
-                kind: event::KeyEventKind::Press,
-                state: KeyEventState::NONE,
             })
         })
         .collect::<Vec<_>>()
