@@ -2,7 +2,6 @@ use clap::Parser;
 use gitu::{cli::Args, error::Error, term, Res};
 use log::LevelFilter;
 use ratatui::Terminal;
-use std::{backtrace::Backtrace, panic};
 
 pub fn main() -> Res<()> {
     let args = Args::parse();
@@ -19,31 +18,20 @@ pub fn main() -> Res<()> {
             .map_err(Error::OpenLogFile)?;
     }
 
-    panic::set_hook(Box::new(|panic_info| {
-        term::cleanup_alternate_screen();
-        term::cleanup_raw_mode();
-
-        eprintln!("{}", panic_info);
-        eprintln!("trace: \n{}", Backtrace::force_capture());
-    }));
+    let mut terminal = Terminal::new(term::create_backend()?).map_err(Error::Term)?;
 
     if args.print {
-        setup_term_and_run(&args)?;
-    } else {
-        term::alternate_screen(|| term::raw_mode(|| setup_term_and_run(&args)))?
+        return gitu::run(&args, &mut terminal);
     }
 
-    Ok(())
-}
-
-fn setup_term_and_run(args: &Args) -> Res<()> {
-    log::debug!("Initializing terminal backend");
-    let mut terminal = Terminal::new(term::backend()).map_err(Error::Term)?;
+    terminal.backend_mut().enter_alternate_screen()?;
+    terminal.backend_mut().enable_raw_mode()?;
 
     // Prevents cursor flash when opening gitu
     terminal.hide_cursor().map_err(Error::Term)?;
     terminal.clear().map_err(Error::Term)?;
 
-    log::debug!("Starting app");
-    gitu::run(args, &mut terminal)
+    gitu::run(&args, &mut terminal)?;
+
+    Ok(())
 }
