@@ -1,5 +1,10 @@
 use super::{Action, OpTrait};
-use crate::{items::TargetData, menu::arg::Arg, state::State, term::Term};
+use crate::{
+    app::{App, State},
+    item_data::ItemData,
+    menu::arg::Arg,
+    term::Term,
+};
 use std::{
     ffi::{OsStr, OsString},
     process::Command,
@@ -25,14 +30,14 @@ pub(crate) fn init_args() -> Vec<Arg> {
 
 pub(crate) struct Commit;
 impl OpTrait for Commit {
-    fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(Rc::new(|state: &mut State, term: &mut Term| {
+    fn get_action(&self, _target: &ItemData) -> Option<Action> {
+        Some(Rc::new(|app: &mut App, term: &mut Term| {
             let mut cmd = Command::new("git");
             cmd.args(["commit"]);
-            cmd.args(state.pending_menu.as_ref().unwrap().args());
+            cmd.args(app.state.pending_menu.as_ref().unwrap().args());
 
-            state.close_menu();
-            state.run_cmd_interactive(term, cmd)?;
+            app.close_menu();
+            app.run_cmd_interactive(term, cmd)?;
             Ok(())
         }))
     }
@@ -44,14 +49,14 @@ impl OpTrait for Commit {
 
 pub(crate) struct CommitAmend;
 impl OpTrait for CommitAmend {
-    fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(Rc::new(|state: &mut State, term: &mut Term| {
+    fn get_action(&self, _target: &ItemData) -> Option<Action> {
+        Some(Rc::new(|app: &mut App, term: &mut Term| {
             let mut cmd = Command::new("git");
             cmd.args(["commit", "--amend"]);
-            cmd.args(state.pending_menu.as_ref().unwrap().args());
+            cmd.args(app.state.pending_menu.as_ref().unwrap().args());
 
-            state.close_menu();
-            state.run_cmd_interactive(term, cmd)?;
+            app.close_menu();
+            app.run_cmd_interactive(term, cmd)?;
             Ok(())
         }))
     }
@@ -61,18 +66,37 @@ impl OpTrait for CommitAmend {
     }
 }
 
+pub(crate) struct CommitExtend;
+impl OpTrait for CommitExtend {
+    fn get_action(&self, _target: &ItemData) -> Option<Action> {
+        Some(Rc::new(|app: &mut App, term: &mut Term| {
+            let mut cmd = Command::new("git");
+            cmd.args(["commit", "--amend", "--no-edit"]);
+            cmd.args(app.state.pending_menu.as_ref().unwrap().args());
+
+            app.close_menu();
+            app.run_cmd_interactive(term, cmd)?;
+            Ok(())
+        }))
+    }
+
+    fn display(&self, _state: &State) -> String {
+        "extend".into()
+    }
+}
+
 pub(crate) struct CommitFixup;
 impl OpTrait for CommitFixup {
-    fn get_action(&self, target: Option<&TargetData>) -> Option<Action> {
+    fn get_action(&self, target: &ItemData) -> Option<Action> {
         match target {
-            Some(TargetData::Commit(r)) => {
-                let rev = OsString::from(r);
+            ItemData::Commit { oid, .. } => {
+                let rev = OsString::from(oid);
 
-                Some(Rc::new(move |state: &mut State, term: &mut Term| {
-                    let args = state.pending_menu.as_ref().unwrap().args();
+                Some(Rc::new(move |app: &mut App, term: &mut Term| {
+                    let args = app.state.pending_menu.as_ref().unwrap().args();
 
-                    state.close_menu();
-                    state.run_cmd_interactive(term, commit_fixup_cmd(&args, &rev))
+                    app.close_menu();
+                    app.run_cmd_interactive(term, commit_fixup_cmd(&args, &rev))
                 }))
             }
             _ => None,
@@ -98,18 +122,18 @@ fn commit_fixup_cmd(args: &[OsString], rev: &OsStr) -> Command {
 
 pub(crate) struct CommitInstantFixup;
 impl OpTrait for CommitInstantFixup {
-    fn get_action(&self, target: Option<&TargetData>) -> Option<Action> {
+    fn get_action(&self, target: &ItemData) -> Option<Action> {
         match target {
-            Some(TargetData::Commit(r)) => {
-                let rev = OsString::from(r);
+            ItemData::Commit { oid, .. } => {
+                let rev = OsString::from(oid);
 
-                Some(Rc::new(move |state: &mut State, term: &mut Term| {
-                    let args = state.pending_menu.as_ref().unwrap().args();
+                Some(Rc::new(move |app: &mut App, term: &mut Term| {
+                    let args = app.state.pending_menu.as_ref().unwrap().args();
 
-                    state.close_menu();
+                    app.close_menu();
 
-                    state.run_cmd(term, &[], commit_fixup_cmd(&args, &rev))?;
-                    state.run_cmd(term, &[], rebase_autosquash_cmd(&rev))
+                    app.run_cmd(term, &[], commit_fixup_cmd(&args, &rev))?;
+                    app.run_cmd(term, &[], rebase_autosquash_cmd(&rev))
                 }))
             }
             _ => None,
