@@ -1,6 +1,12 @@
 use serde::{Deserialize, Serialize};
 
-use crate::{items::TargetData, menu::Menu, state::State, term::Term, Res};
+use crate::{
+    app::{App, State},
+    item_data::ItemData,
+    menu::Menu,
+    term::Term,
+    Res,
+};
 use std::{fmt::Display, rc::Rc};
 
 pub(crate) mod branch;
@@ -22,12 +28,12 @@ pub(crate) mod stage;
 pub(crate) mod stash;
 pub(crate) mod unstage;
 
-pub(crate) type Action = Rc<dyn FnMut(&mut State, &mut Term) -> Res<()>>;
+pub(crate) type Action = Rc<dyn FnMut(&mut App, &mut Term) -> Res<()>>;
 
 pub(crate) trait OpTrait {
     /// Get the implementation (which may or may not exist) of the Op given some TargetData.
     /// This indirection allows Gitu to show a contextual menu of applicable actions.
-    fn get_action(&self, target: Option<&TargetData>) -> Option<Action>;
+    fn get_action(&self, target: &ItemData) -> Option<Action>;
 
     /// This indicates whether the Op is meant to read and
     /// act on TargetData. Those are listed differently in the help menu.
@@ -47,6 +53,7 @@ pub(crate) enum Op {
     Delete,
     Commit,
     CommitAmend,
+    CommitExtend,
     FetchAll,
     FetchElsewhere,
     LogCurrent,
@@ -59,6 +66,8 @@ pub(crate) enum Op {
     RebaseAbort,
     RebaseContinue,
     RebaseElsewhere,
+    RemoveRemote,
+    RenameRemote,
     ShowRefs,
     Stash,
     StashApply,
@@ -128,6 +137,7 @@ impl Op {
             Op::Delete => Box::new(branch::Delete),
             Op::Commit => Box::new(commit::Commit),
             Op::CommitAmend => Box::new(commit::CommitAmend),
+            Op::CommitExtend => Box::new(commit::CommitExtend),
             Op::FetchAll => Box::new(fetch::FetchAll),
             Op::FetchElsewhere => Box::new(fetch::FetchElsewhere),
             Op::LogCurrent => Box::new(log::LogCurrent),
@@ -167,6 +177,8 @@ impl Op {
             Op::CopyHash => Box::new(copy_hash::CopyHash),
 
             Op::AddRemote => Box::new(remote::AddRemote),
+            Op::RemoveRemote => Box::new(remote::RemoveRemote),
+            Op::RenameRemote => Box::new(remote::RenameRemote),
         }
     }
 }
@@ -191,10 +203,10 @@ impl Display for Menu {
     }
 }
 
-pub(crate) fn confirm(state: &mut State, term: &mut Term, prompt: &'static str) -> Res<()> {
-    state.confirm(term, prompt)
+pub(crate) fn confirm(app: &mut App, term: &mut Term, prompt: &'static str) -> Res<()> {
+    app.confirm(term, prompt)
 }
 
-pub(crate) fn selected_rev(state: &State) -> Option<String> {
+pub(crate) fn selected_rev(state: &App) -> Option<String> {
     state.selected_rev()
 }
