@@ -1,9 +1,15 @@
-use ratatui::prelude::*;
+use crate::item_data::ItemData;
+use ratatui::{
+    buffer::Buffer,
+    layout::{Rect, Size},
+    text::Line,
+    widgets::Widget,
+};
 
-use crate::{config::Config, items::TargetData, Res};
+use crate::{config::Config, items::hash, Res};
 
 use super::Item;
-use std::{borrow::Cow, collections::HashSet, rc::Rc};
+use std::{collections::HashSet, rc::Rc};
 
 pub(crate) mod log;
 pub(crate) mod show;
@@ -27,7 +33,7 @@ pub(crate) struct Screen {
     refresh_items: Box<dyn Fn() -> Res<Vec<Item>>>,
     items: Vec<Item>,
     line_index: Vec<usize>,
-    collapsed: HashSet<Cow<'static, str>>,
+    collapsed: HashSet<u64>,
 }
 
 impl Screen {
@@ -41,7 +47,7 @@ impl Screen {
             .collapsed_sections
             .clone()
             .into_iter()
-            .map(Cow::Owned)
+            .map(hash)
             .collect();
 
         let mut screen = Self {
@@ -63,7 +69,7 @@ impl Screen {
             .iter()
             .filter(|item| item.default_collapsed)
             .for_each(|item| {
-                screen.collapsed.insert(item.id.clone());
+                screen.collapsed.insert(item.id);
             });
         screen.update_line_index();
 
@@ -78,10 +84,7 @@ impl Screen {
     fn find_first_hunk(&mut self) -> Option<usize> {
         (0..self.line_index.len()).find(|&line_i| {
             !self.at_line(line_i).unselectable
-                && matches!(
-                    self.at_line(line_i).target_data,
-                    Some(TargetData::Hunk { .. })
-                )
+                && matches!(self.at_line(line_i).data, ItemData::Hunk { .. })
         })
     }
 
@@ -140,9 +143,7 @@ impl Screen {
         let item = self.at_line(line_i);
         match nav_mode {
             NavMode::Normal => {
-                let target_data = item.target_data.as_ref();
-                let is_hunk_line =
-                    target_data.is_some_and(|d| matches!(d, TargetData::HunkLine { .. }));
+                let is_hunk_line = matches!(item.data, ItemData::HunkLine { .. });
 
                 !item.unselectable && !is_hunk_line
             }
@@ -196,7 +197,7 @@ impl Screen {
             if self.collapsed.contains(&selected.id) {
                 self.collapsed.remove(&selected.id);
             } else {
-                self.collapsed.insert(selected.id.clone());
+                self.collapsed.insert(selected.id);
             }
         }
 
@@ -226,8 +227,8 @@ impl Screen {
             return NavMode::Normal;
         }
 
-        match self.get_selected_item().target_data {
-            Some(TargetData::HunkLine { .. }) => NavMode::IncludeHunkLines,
+        match self.get_selected_item().data {
+            ItemData::HunkLine { .. } => NavMode::IncludeHunkLines,
             _ => NavMode::Normal,
         }
     }
@@ -295,18 +296,19 @@ impl Screen {
 
         self.line_index[scan_highlight_range]
             .iter()
-            .scan(None, |highlight_depth, item_i| {
-                let item = &self.items[*item_i];
-                if self.line_index[self.cursor] == *item_i {
+            .scan(None, |highlight_depth, item_index| {
+                let item = &self.items[*item_index];
+                if self.line_index[self.cursor] == *item_index {
                     *highlight_depth = Some(item.depth);
                 } else if highlight_depth.is_some_and(|s| s >= item.depth) {
                     *highlight_depth = None;
                 };
+                let display = item.to_line(Rc::clone(&self.config));
 
                 Some(LineView {
-                    item_index: *item_i,
+                    item_index: *item_index,
                     item,
-                    display: &item.display,
+                    display,
                     highlighted: highlight_depth.is_some(),
                 })
             })
@@ -317,7 +319,7 @@ impl Screen {
 struct LineView<'a> {
     item_index: usize,
     item: &'a Item,
-    display: &'a Line<'a>,
+    display: Line<'a>,
     highlighted: bool,
 }
 
@@ -347,12 +349,15 @@ impl Widget for &Screen {
                 }
             }
 
-            line.display.render(indented_line_area, buf);
-            let overflow = line.display.width() > line_area.width as usize;
+            let line_width = line.display.width();
 
-            if self.is_collapsed(line.item) && line.display.width() > 0 || overflow {
-                let line_end =
-                    (indented_line_area.x + line.display.width() as u16).min(area.width - 1);
+            line.display.render(indented_line_area, buf);
+            let overflow = line_width > line_area.width as usize;
+
+            let line_width = line_width as u16;
+
+            if self.is_collapsed(line.item) && line_width > 0 || overflow {
+                let line_end = (indented_line_area.x + line_width).min(area.width - 1);
                 buf[(line_end, line_index as u16)].set_char('…');
             }
 
